@@ -9,7 +9,7 @@
 
 from abc import abstractclassmethod
 from termuxmenu.console import Console
-from termuxmenu.error.logger import ErrorLog
+from termuxmenu.logger import ErrorLog
 
 class DefaultConsole(Console):
     def __init__(self,error_log: ErrorLog) -> None:
